import type { OpenAPIV3 } from "openapi-types";
export declare function camelCase(str: string): string;
export declare function pascalCase(str: string): string;
/**
 * Sanitizes a property name to ensure it's a valid JavaScript identifier.
 * If the name is already a valid identifier (starts with letter/underscore/$ and contains only letters/numbers/underscore/$),
 * returns it as-is. Otherwise wraps it in quotes to make it a valid property accessor.
 *
 * For example:
 * - sanitizePropertyName("validName") => "validName"
 * - sanitizePropertyName("invalid-name") => "'invalid-name'"
 * - sanitizePropertyName("123invalid") => "'123invalid'"
 *
 * @param name The property name to sanitize
 * @returns The sanitized property name, quoted if needed
 */
export declare function sanitizePropertyName(name: string): string;
/**
 * Sanitizes a type name to ensure it's a valid TypeScript type identifier.
 * Replaces any characters that aren't alphanumeric or underscore with an underscore.
 *
 * For example:
 * - sanitizeTypeName("ValidType") => "ValidType"
 * - sanitizeTypeName("invalid-type") => "invalid_type"
 * - sanitizeTypeName("type.name") => "type_name"
 * - sanitizeTypeName("type/name") => "type_name"
 *
 * This is used to convert operation IDs and response names from the OpenAPI spec
 * into valid TypeScript type names.
 *
 * @param name The type name to sanitize
 * @returns The sanitized type name with invalid characters replaced by underscores
 */
export declare function sanitizeTypeName(name: string): string;
export declare function specTitle(spec: OpenAPIV3.Document): string;
/**
 * Converts an OpenAPI schema object into a TypeScript type string.
 *
 * Handles:
 * - References ($ref) by extracting the type name
 * - Nullable types by appending "| null"
 * - Enums by creating union types of the values
 * - Basic types (string, number, boolean)
 * - Binary format strings as a union with file metadata object
 * - Arrays by recursively getting the item type
 * - Objects with properties by creating interfaces
 * - Objects with additionalProperties as Records
 * - Fallback to "any" for unknown types
 *
 * @param param - The OpenAPI schema/parameter object to convert
 * @returns The TypeScript type as a string
 */
export declare function getTypeFromSchema(schema: OpenAPIV3.ParameterObject | OpenAPIV3.SchemaObject | OpenAPIV3.ReferenceObject | undefined): string | undefined;
